function LoadSettings()
	iniFile = cIniFile()
	iniFile:ReadFile( PLUGIN:GetLocalDirectory().."/bizzare_settings.ini" )
	Settings.LiveMinimum = iniFile:GetValueSetI( "Settings", "LiveMinimum", Settings.LiveMinimum )
	Settings.LiveMaximum = iniFile:GetValueSetI( "Settings", "LiveMaximum", Settings.LiveMaximum )
	Settings.Birth = iniFile:GetValueSetI( "Settings", "Birth", Settings.Birth )
	Settings.TicksPerUpdate = iniFile:GetValueSetI( "Settings", "TicksPerUpdate", Settings.TicksPerUpdate )
	iniFile:WriteFile( PLUGIN:GetLocalDirectory().."/bizzare_settings.ini" )
end
function SaveSettings()
	iniFile = cIniFile()
	iniFile:ReadFile( PLUGIN:GetLocalDirectory().."/bizzare_settings.ini" )
	iniFile:SetValueI( "Settings", "LiveMinimum", Settings.LiveMinimum, false )
	iniFile:SetValueI( "Settings", "LiveMaximum", Settings.LiveMaximum, false )
	iniFile:SetValueI( "Settings", "Birth", Settings.Birth, false )
	iniFile:SetValueI( "Settings", "TicksPerUpdate", Settings.TicksPerUpdate, false )
	iniFile:WriteFile( PLUGIN:GetLocalDirectory().."/bizzare_settings.ini" )
end
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
function Update()
	blocksProcessed = 0
	for y, ySlice in pairs( Bizzare.Map ) do
		for x, xLine in pairs( ySlice ) do
			for z, blockType in pairs( xLine ) do
				if( blockType == Bizzare.Block ) then
					ProcessBlock( x, y, z, blockType )
					blocksProcessed = blocksProcessed + 1
				end
			end
		end
	end
	LOGINFO( "Update() successfull O_o Processed: "..blocksProcessed )
	ApplyNewMap()
end
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
function GetBlock( inX, inY, inZ, inMap )
	registered = false
	blockType = Bizzare.Air
	if( inMap[inY] ~= nil ) then
		if( inMap[inY][inX] ~= nil ) then
			if( inMap[inY][inX][inZ] ~= nil ) then
				registered = true
				blockType = inMap[inY][inX][inZ]
			end
		end
	end
	return registered, blockType
end

function SetBlock( inX, inY, inZ, inType, inMap )
	if( inMap[inY] == nil )				then inMap[inY] = {}			end
	if( inMap[inY][inX] == nil )		then inMap[inY][inX] = {}		end
	if( inMap[inY][inX][inZ] == nil )	then inMap[inY][inX][inZ] = {}	end
	inMap[inY][inX][inZ] = inType
end

function RemoveEntry( inX, inY, inZ, inMap )
	if( inMap[inY] == nil )		then return end
	if( inMap[inY][inX] == nil )	then return end
	if( inMap[inY][inX][inZ] == nil )	then return end
	inMap[inY][inX][inZ] = nil
end
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
function ProcessBlock( inX, inY, inZ, inType )
	value = SurroundingBlocks( inX, inY, inZ, inType )
	if( inType == Bizzare.Air ) then
		if( value == Settings.Birth ) then
			SetBlock( inX, inY, inZ, Bizzare.Block, Bizzare.MapNext )
		end
	else
		if( value < Settings.LiveMinimum or value > Settings.LiveMaximum ) then
			SetBlock( inX, inY, inZ, Bizzare.Air, Bizzare.MapNext )
		end
	end
end

function SurroundingBlocks( inX, inY, inZ, inType )
	result = 0
	for y = -1, 1 do
		for x = -1, 1 do
			for z = -1, 1 do
				if( not( x == 0 and y == 0 and z == 0 ) ) then
					valid, blockType, blockMeta = Bizzare.World:GetBlockTypeMeta( inX + x, inY + y, inZ + z )
					if( valid ) then
						if( blockType == Bizzare.Block and blockMeta == Bizzare.BlockMeta ) then
							result = result + 1
							registered, mapBlockType = GetBlock( inX + x, inY + y, inZ + z, Bizzare.Map )
							if( not registered ) then
								SetBlock( inX + x, inY + y, inZ + z, Bizzare.Block, Bizzare.Map )
							end
						elseif( blockType == Bizzare.Air ) then
							if( inType == Bizzare.Block ) then
								ProcessBlock( inX + x, inY + y, inZ + z, Bizzare.Air )
							end
						end
					end
				end
			end
		end
	end
	return result
end
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
function ApplyNewMap()
	for y, ySlice in pairs( Bizzare.MapNext ) do
		for x, xLine in pairs( ySlice ) do
			for z, blockType in pairs( xLine ) do
				if( blockType == Bizzare.Air ) then
					RemoveEntry( x, y, z, Bizzare.Map )
					RemoveBlockAt( x, y, z )
				elseif( blockType == Bizzare.Block ) then
					SetBlock( x, y, z, blockType, Bizzare.Map )
					AddBlockAt( x, y, z )
				end
			end
		end
	end
	Bizzare.MapNext = {}
	LOGINFO( "Map applied!" )
end
--|||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||||
function AddBlockAt( inX, inY, inZ )
	Bizzare.World:QueueSetBlock( inX, inY, inZ, Bizzare.Block, Bizzare.BlockMeta, UpdateDelay )
end

function RemoveBlockAt( inX, inY, inZ )
	Bizzare.World:QueueSetBlock( inX, inY, inZ, Bizzare.Air, 0, UpdateDelay )
end